@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: ogrmerge.py 545d0423e15cc28a5aca3a9852fab80b80601162 2018-12-12 11:49:36 +1300 Craig de Stigter $
+# $Id: ogrmerge.py 34b4a8f2f2f9c606b8f3db1b9211f48f99cd32fd 2019-03-19 17:06:24 +0100 Even Rouault $
 #
 # Project:  GDAL/OGR samples
 # Purpose:  Merge the content of several vector datasets into a single one.
@@ -453,13 +453,15 @@ def process(argv, progress=None, progress_arg=None):
 
                 writer.open_element('OGRVRTLayer',
                                     attrs={'name': layer_name})
-                attrs = None
+                attrs = {}
                 if EQUAL(output_format, 'VRT') and \
                    os.path.exists(src_dsname) and \
                    not os.path.isabs(src_dsname) and \
                    '/' not in vrt_filename and \
                    '\\' not in vrt_filename:
-                    attrs = {'relativeToVRT': '1'}
+                    attrs['relativeToVRT'] = '1'
+                if single_layer:
+                    attrs['shared'] = '1'
                 writer.write_element_value('SrcDataSource', src_dsname,
                                            attrs=attrs)
                 writer.write_element_value('SrcLayer', src_lyr.GetName())
@@ -550,13 +552,15 @@ def process(argv, progress=None, progress_arg=None):
 
                 writer.open_element('OGRVRTLayer',
                                     attrs={'name': layer_name})
-                attrs = None
+                attrs = {}
                 if EQUAL(output_format, 'VRT') and \
                    os.path.exists(src_dsname) and \
                    not os.path.isabs(src_dsname) and \
                    '/' not in vrt_filename and \
                    '\\' not in vrt_filename:
-                    attrs = {'relativeToVRT': '1'}
+                    attrs['relativeToVRT'] = '1'
+                if single_layer:
+                    attrs['shared'] = '1'
                 writer.write_element_value('SrcDataSource', src_dsname,
                                            attrs=attrs)
                 writer.write_element_value('SrcLayer', src_lyr_name)
